pub struct LiveChangesStream { /* private fields */ }Expand description
A live changes stream that yields change events as they happen.
In live mode, after fetching existing changes, it waits for notifications via a broadcast channel or polls at regular intervals.
Implementations
Sourceimpl LiveChangesStream
impl LiveChangesStream
pub fn new( adapter: Arc<dyn Adapter>, receiver: Option<ChangeReceiver>, opts: ChangesStreamOptions, ) -> Self
Sourcepub async fn next_change(&mut self) -> Option<ChangeEvent>
pub async fn next_change(&mut self) -> Option<ChangeEvent>
Get the next change event, blocking if in live mode.