Crate rouchdb_changes

Crate rouchdb_changes 

Structs

ChangeNotification
A notification that a change occurred, sent through the broadcast channel.
ChangeReceiver
A receiver for change notifications.
ChangeSender
A sender for change notifications. Adapters use this to notify listeners when documents are written.
ChangesStreamOptions
Configuration for a changes stream.
LiveChangesStream
A live changes stream that yields change events as they happen.

Functions

get_changes
Fetch changes from an adapter in one-shot mode.